@@ -43,12 +43,12 @@ var searchData=
   ['tds_5fascii_5fto_5fucs2_40',['tds_ascii_to_ucs2',['../a00599.html#gad05fc65e1d505c68d14c82b99a00e4eb',1,'query.c']]],
   ['tds_5fauthentication_41',['tds_authentication',['../a01311.html',1,'']]],
   ['tds_5fbcp_5fdirections_42',['tds_bcp_directions',['../a00434.html#ad5c5c8cb776334af4b0ebf7a0d740cb2',1,'tds.h']]],
-  ['tds_5fbcp_5fdone_43',['tds_bcp_done',['../a00434.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c'],['../a00254.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c']]],
+  ['tds_5fbcp_5fdone_43',['tds_bcp_done',['../a00254.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c'],['../a00434.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c']]],
   ['tds_5fbcp_5ffread_44',['tds_bcp_fread',['../a00254.html#a86ac92bd8a3c61a413d27150ec9bc202',1,'tds_bcp_fread(TDSSOCKET *tds, TDSICONV *char_conv, FILE *stream, const char *terminator, size_t term_len, char **outbuf, size_t *outbytes):&#160;bulk.c'],['../a00434.html#a8184311543c685f2ee0bcccfb725ca02',1,'tds_bcp_fread(TDSSOCKET *tds, TDSICONV *conv, FILE *stream, const char *terminator, size_t term_len, char **outbuf, size_t *outbytes):&#160;bulk.c']]],
-  ['tds_5fbcp_5finit_45',['tds_bcp_init',['../a00254.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00434.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
+  ['tds_5fbcp_5finit_45',['tds_bcp_init',['../a00434.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00254.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
   ['tds_5fbcp_5frow_5ffree_46',['tds_bcp_row_free',['../a00254.html#a55bd2715b2897e9592cbbd9c6e3c86f6',1,'bulk.c']]],
   ['tds_5fbcp_5fsend_5frecord_47',['tds_bcp_send_record',['../a00434.html#ad9e44450025cbcee1ad81d7e5a2cc099',1,'tds_bcp_send_record(TDSSOCKET *tds, TDSBCPINFO *bcpinfo, tds_bcp_get_col_data get_col_data, tds_bcp_null_error null_error, int offset):&#160;bulk.c'],['../a00254.html#ad9e44450025cbcee1ad81d7e5a2cc099',1,'tds_bcp_send_record(TDSSOCKET *tds, TDSBCPINFO *bcpinfo, tds_bcp_get_col_data get_col_data, tds_bcp_null_error null_error, int offset):&#160;bulk.c']]],
-  ['tds_5fbcp_5fstart_48',['tds_bcp_start',['../a00434.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00254.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
+  ['tds_5fbcp_5fstart_48',['tds_bcp_start',['../a00254.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00434.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
   ['tds_5fbcp_5fstart_5fcopy_5fin_49',['tds_bcp_start_copy_in',['../a00254.html#a5eec23828b0610c58de248c4edb53879',1,'tds_bcp_start_copy_in(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00434.html#a5eec23828b0610c58de248c4edb53879',1,'tds_bcp_start_copy_in(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
   ['tds_5fbcp_5fstart_5finsert_5fstmt_50',['tds_bcp_start_insert_stmt',['../a00254.html#ab4d7e5309152f54613d52c8469a07fd8',1,'bulk.c']]],
   ['tds_5fbcpcoldata_51',['tds_bcpcoldata',['../a01259.html',1,'']]],
@@ -157,7 +157,7 @@ var searchData=
   ['tds_5fgoodwrite_154',['tds_goodwrite',['../a00600.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c'],['../a00600.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c']]],
   ['tds_5fheader_155',['TDS_HEADER',['../a01159.html',1,'']]],
   ['tds_5fheaders_156',['tds_headers',['../a01239.html',1,'']]],
-  ['tds_5ficonv_157',['tds_iconv',['../a00597.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *char_conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c'],['../a00597.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c']]],
+  ['tds_5ficonv_157',['tds_iconv',['../a00597.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c'],['../a00597.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *char_conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c']]],
   ['tds_5ficonv_5falloc_158',['tds_iconv_alloc',['../a01512.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c'],['../a00434.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c']]],
   ['tds_5ficonv_5ffrom_5fcollate_159',['tds_iconv_from_collate',['../a00597.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c'],['../a00597.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c']]],
   ['tds_5ficonv_5fget_5finfo_160',['tds_iconv_get_info',['../a00597.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c'],['../a00597.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c']]],
@@ -310,61 +310,62 @@ var searchData=
   ['tds_5ftoken_5fname_307',['tds_token_name',['../a00601.html#ga7f24a7af985cd320788122e98072b7af',1,'token.c']]],
   ['tds_5ftvp_308',['tds_tvp',['../a01335.html',1,'']]],
   ['tds_5ftvp_5frow_309',['tds_tvp_row',['../a01331.html',1,'']]],
-  ['tds_5funget_5fbyte_310',['tds_unget_byte',['../a00600.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c'],['../a00600.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c']]],
-  ['tds_5fupd_5fcol_311',['tds_upd_col',['../a01283.html',1,'']]],
-  ['tds_5fvariant_312',['tds_variant',['../a01251.html',1,'']]],
-  ['tds_5fvarmax_5fstream_313',['tds_varmax_stream',['../a00791.html',1,'']]],
-  ['tds_5fversion_314',['tds_version',['../a01235.html#a8f9f756b25fd18916a6080f9c22f835d',1,'tds_login']]],
-  ['tds_5fwillconvert_315',['tds_willconvert',['../a00596.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c'],['../a00596.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c']]],
-  ['tds_5fwrite_5fdump_316',['tds_write_dump',['../a00434.html#a02866a1bf7da5ab66a994217fcceb1b7',1,'log.c']]],
-  ['tds_5fwritetext_5fcontinue_317',['tds_writetext_continue',['../a00254.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c'],['../a00434.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c']]],
-  ['tds_5fwritetext_5fend_318',['tds_writetext_end',['../a00254.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c'],['../a00434.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c']]],
-  ['tds_5fwritetext_5fstart_319',['tds_writetext_start',['../a00254.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c'],['../a00434.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c']]],
-  ['tds_5fwriting_320',['TDS_WRITING',['../a00434.html#a87cdae58f91ebe9229206bf0628f8e33a4a4fcc1840bee1e09521f08a0184d025',1,'tds.h']]],
-  ['tdsblob_321',['TDSBLOB',['../a00434.html#a47b154752431b2379988dbfdff394577',1,'tds.h']]],
-  ['tdscursor_322',['TDSCURSOR',['../a00434.html#afe061eb245f3006d93940a20415692a7',1,'tds.h']]],
-  ['tdsdaterec_323',['tdsdaterec',['../a01215.html',1,'tdsdaterec'],['../a00434.html#a3b40b4faf314267146c2005e56eebe7b',1,'TDSDATEREC:&#160;tds.h']]],
-  ['tdsdatetime_324',['tdsdatetime',['../a01143.html',1,'']]],
-  ['tdsdatetime4_325',['tdsdatetime4',['../a01147.html',1,'']]],
-  ['tdsdbopen_326',['tdsdbopen',['../a00590.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c'],['../a00590.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c']]],
-  ['tdsdump_5fclose_327',['tdsdump_close',['../a00434.html#a2f00fc0907d3bb04ce0eeb9738e08d0c',1,'log.c']]],
-  ['tdsdump_5fcol_328',['tdsdump_col',['../a00434.html#aaee3fe5c514ce5570c9548de9b16e0d9',1,'log.c']]],
-  ['tdsdump_5fdump_5fbuf_5fimpl_329',['tdsdump_dump_buf_impl',['../a00434.html#a60cebdbb8c6750d36c68fcb1949ce83a',1,'log.c']]],
-  ['tdsdump_5flog_5fimpl_330',['tdsdump_log_impl',['../a00434.html#aa45e90c7bdceb30a826c123ad66da9e4',1,'log.c']]],
-  ['tdsdump_5foff_331',['tdsdump_off',['../a00434.html#ae3e5e04822595c54f86db66d9e40b93a',1,'log.c']]],
-  ['tdsdump_5foff_5fitem_332',['tdsdump_off_item',['../a01339.html',1,'']]],
-  ['tdsdump_5fon_333',['tdsdump_on',['../a00434.html#ae5f50062ebebe46b951e5308cb2f5d7e',1,'log.c']]],
-  ['tdsdump_5fopen_334',['tdsdump_open',['../a00434.html#a24471508ddfde7cc0f8577801e70c42f',1,'log.c']]],
-  ['tdsdynamic_335',['TDSDYNAMIC',['../a00434.html#a856d78b7438fef3d6e6c0a8e4566d978',1,'tds.h']]],
-  ['tdsenv_336',['TDSENV',['../a00434.html#a42c559939ed16a39c0318a6f543c576e',1,'tds.h']]],
-  ['tdserror_337',['tdserror',['../a00434.html#abf18b98efef6ce2dc0b97d658a3a1918',1,'util.c']]],
-  ['tdsfilestream_338',['TDSFILESTREAM',['../a00254.html#ac2b7f7b7bb486f90e1053bfb829ca2ba',1,'bulk.c']]],
-  ['tdsiconvdir_339',['tdsiconvdir',['../a01055.html',1,'']]],
-  ['tdsiconvinfo_340',['tdsiconvinfo',['../a01059.html',1,'']]],
-  ['tdsmoney_341',['tdsmoney',['../a01135.html',1,'']]],
-  ['tdsmoney4_342',['tdsmoney4',['../a01139.html',1,'']]],
-  ['tdsnumeric_343',['tdsnumeric',['../a01127.html',1,'']]],
-  ['tdsoldmoney_344',['tdsoldmoney',['../a01131.html',1,'']]],
-  ['tdspbcb_345',['TDSPBCB',['../a00254.html#af31a5af3c7480dc3a16576dfc84f3b06',1,'bulk.c']]],
-  ['tdsunique_346',['tdsunique',['../a01151.html',1,'']]],
-  ['tdsvariant_347',['TDSVARIANT',['../a00434.html#a25488abe3449d4cdaaa97587d34f9174',1,'tds.h']]],
-  ['tdsvername_5ft_348',['tdsvername_t',['../a00783.html',1,'']]],
-  ['term_5flen_349',['term_len',['../a00763.html#aae893302d33ee1e9d83c3d85d7390dca',1,'tds_file_stream']]],
-  ['terminator_350',['terminator',['../a00763.html#a463c28a7d862c0a6d7bf3170dd614dc0',1,'tds_file_stream']]],
-  ['the_20db_20lib_20api_351',['The db-lib API',['../a00583.html',1,'']]],
-  ['time_352',['time',['../a01211.html#afd6a58ec251f2c08a040917ba5a8cd3f',1,'TDS_DATETIMEALL::time'],['../a01435.html#a6bb5dcd5b47813b71934546e0c60e035',1,'DBDATETIMEALL::time']]],
-  ['timezone_353',['timezone',['../a01215.html#a624e21e65d0ae89797b3a7eadc48829f',1,'tdsdaterec']]],
-  ['tm_5fhour_354',['tm_hour',['../a00787.html#a6ece03e77f69035da83d5739e16ef905',1,'tds_time']]],
-  ['tm_5fmday_355',['tm_mday',['../a00787.html#a8dfc26d484c247040f521f20288651f1',1,'tds_time']]],
-  ['tm_5fmin_356',['tm_min',['../a00787.html#ab50f30e05dc6b493d347918ab7ded1e9',1,'tds_time']]],
-  ['tm_5fmon_357',['tm_mon',['../a00787.html#adce28126e9bbd4ef005e3bf181d59745',1,'tds_time']]],
-  ['tm_5fns_358',['tm_ns',['../a00787.html#a386f1cfcabbe3ed86afe72bed75778cf',1,'tds_time']]],
-  ['tm_5fsec_359',['tm_sec',['../a00787.html#adeb5e3f535662c0341d28f8d669cb59b',1,'tds_time']]],
-  ['tm_5fyear_360',['tm_year',['../a00787.html#a3e27d50ebb5196356a6a8a9b495c8758',1,'tds_time']]],
-  ['tmp_5fbuf_361',['tmp_buf',['../a00651.html',1,'']]],
-  ['tmp_5fcol_5fstruct_362',['tmp_col_struct',['../a00747.html',1,'']]],
-  ['to_20add_20a_20new_20type_363',['How to add a new type',['../a01468.html',1,'']]],
-  ['todo_20list_364',['Todo List',['../a00581.html',1,'']]],
-  ['token_2ec_365',['token.c',['../a00251.html',1,'']]],
-  ['type_366',['type',['../a01468.html',1,'How to add a new type'],['../a01291.html#a889aafdde1d57c9be0585326022831f0',1,'tds_cursor::type']]]
+  ['tds_5fu32toa_5ffast_5fright_310',['tds_u32toa_fast_right',['../a00596.html#gadeab52fc2e1c455d261085971747bf2b',1,'tds_u32toa_fast_right(char out[10], uint32_t v):&#160;convert.c'],['../a00596.html#gadeab52fc2e1c455d261085971747bf2b',1,'tds_u32toa_fast_right(char out[10], uint32_t v):&#160;convert.c']]],
+  ['tds_5funget_5fbyte_311',['tds_unget_byte',['../a00600.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c'],['../a00600.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c']]],
+  ['tds_5fupd_5fcol_312',['tds_upd_col',['../a01283.html',1,'']]],
+  ['tds_5fvariant_313',['tds_variant',['../a01251.html',1,'']]],
+  ['tds_5fvarmax_5fstream_314',['tds_varmax_stream',['../a00791.html',1,'']]],
+  ['tds_5fversion_315',['tds_version',['../a01235.html#a8f9f756b25fd18916a6080f9c22f835d',1,'tds_login']]],
+  ['tds_5fwillconvert_316',['tds_willconvert',['../a00596.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c'],['../a00596.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c']]],
+  ['tds_5fwrite_5fdump_317',['tds_write_dump',['../a00434.html#a02866a1bf7da5ab66a994217fcceb1b7',1,'log.c']]],
+  ['tds_5fwritetext_5fcontinue_318',['tds_writetext_continue',['../a00254.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c'],['../a00434.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c']]],
+  ['tds_5fwritetext_5fend_319',['tds_writetext_end',['../a00254.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c'],['../a00434.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c']]],
+  ['tds_5fwritetext_5fstart_320',['tds_writetext_start',['../a00254.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c'],['../a00434.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c']]],
+  ['tds_5fwriting_321',['TDS_WRITING',['../a00434.html#a87cdae58f91ebe9229206bf0628f8e33a4a4fcc1840bee1e09521f08a0184d025',1,'tds.h']]],
+  ['tdsblob_322',['TDSBLOB',['../a00434.html#a47b154752431b2379988dbfdff394577',1,'tds.h']]],
+  ['tdscursor_323',['TDSCURSOR',['../a00434.html#afe061eb245f3006d93940a20415692a7',1,'tds.h']]],
+  ['tdsdaterec_324',['tdsdaterec',['../a01215.html',1,'tdsdaterec'],['../a00434.html#a3b40b4faf314267146c2005e56eebe7b',1,'TDSDATEREC:&#160;tds.h']]],
+  ['tdsdatetime_325',['tdsdatetime',['../a01143.html',1,'']]],
+  ['tdsdatetime4_326',['tdsdatetime4',['../a01147.html',1,'']]],
+  ['tdsdbopen_327',['tdsdbopen',['../a00590.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c'],['../a00590.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c']]],
+  ['tdsdump_5fclose_328',['tdsdump_close',['../a00434.html#a2f00fc0907d3bb04ce0eeb9738e08d0c',1,'log.c']]],
+  ['tdsdump_5fcol_329',['tdsdump_col',['../a00434.html#aaee3fe5c514ce5570c9548de9b16e0d9',1,'log.c']]],
+  ['tdsdump_5fdump_5fbuf_5fimpl_330',['tdsdump_dump_buf_impl',['../a00434.html#a60cebdbb8c6750d36c68fcb1949ce83a',1,'log.c']]],
+  ['tdsdump_5flog_5fimpl_331',['tdsdump_log_impl',['../a00434.html#aa45e90c7bdceb30a826c123ad66da9e4',1,'log.c']]],
+  ['tdsdump_5foff_332',['tdsdump_off',['../a00434.html#ae3e5e04822595c54f86db66d9e40b93a',1,'log.c']]],
+  ['tdsdump_5foff_5fitem_333',['tdsdump_off_item',['../a01339.html',1,'']]],
+  ['tdsdump_5fon_334',['tdsdump_on',['../a00434.html#ae5f50062ebebe46b951e5308cb2f5d7e',1,'log.c']]],
+  ['tdsdump_5fopen_335',['tdsdump_open',['../a00434.html#a24471508ddfde7cc0f8577801e70c42f',1,'log.c']]],
+  ['tdsdynamic_336',['TDSDYNAMIC',['../a00434.html#a856d78b7438fef3d6e6c0a8e4566d978',1,'tds.h']]],
+  ['tdsenv_337',['TDSENV',['../a00434.html#a42c559939ed16a39c0318a6f543c576e',1,'tds.h']]],
+  ['tdserror_338',['tdserror',['../a00434.html#abf18b98efef6ce2dc0b97d658a3a1918',1,'util.c']]],
+  ['tdsfilestream_339',['TDSFILESTREAM',['../a00254.html#ac2b7f7b7bb486f90e1053bfb829ca2ba',1,'bulk.c']]],
+  ['tdsiconvdir_340',['tdsiconvdir',['../a01055.html',1,'']]],
+  ['tdsiconvinfo_341',['tdsiconvinfo',['../a01059.html',1,'']]],
+  ['tdsmoney_342',['tdsmoney',['../a01135.html',1,'']]],
+  ['tdsmoney4_343',['tdsmoney4',['../a01139.html',1,'']]],
+  ['tdsnumeric_344',['tdsnumeric',['../a01127.html',1,'']]],
+  ['tdsoldmoney_345',['tdsoldmoney',['../a01131.html',1,'']]],
+  ['tdspbcb_346',['TDSPBCB',['../a00254.html#af31a5af3c7480dc3a16576dfc84f3b06',1,'bulk.c']]],
+  ['tdsunique_347',['tdsunique',['../a01151.html',1,'']]],
+  ['tdsvariant_348',['TDSVARIANT',['../a00434.html#a25488abe3449d4cdaaa97587d34f9174',1,'tds.h']]],
+  ['tdsvername_5ft_349',['tdsvername_t',['../a00783.html',1,'']]],
+  ['term_5flen_350',['term_len',['../a00763.html#aae893302d33ee1e9d83c3d85d7390dca',1,'tds_file_stream']]],
+  ['terminator_351',['terminator',['../a00763.html#a463c28a7d862c0a6d7bf3170dd614dc0',1,'tds_file_stream']]],
+  ['the_20db_20lib_20api_352',['The db-lib API',['../a00583.html',1,'']]],
+  ['time_353',['time',['../a01211.html#afd6a58ec251f2c08a040917ba5a8cd3f',1,'TDS_DATETIMEALL::time'],['../a01435.html#a6bb5dcd5b47813b71934546e0c60e035',1,'DBDATETIMEALL::time']]],
+  ['timezone_354',['timezone',['../a01215.html#a624e21e65d0ae89797b3a7eadc48829f',1,'tdsdaterec']]],
+  ['tm_5fhour_355',['tm_hour',['../a00787.html#a6ece03e77f69035da83d5739e16ef905',1,'tds_time']]],
+  ['tm_5fmday_356',['tm_mday',['../a00787.html#a8dfc26d484c247040f521f20288651f1',1,'tds_time']]],
+  ['tm_5fmin_357',['tm_min',['../a00787.html#ab50f30e05dc6b493d347918ab7ded1e9',1,'tds_time']]],
+  ['tm_5fmon_358',['tm_mon',['../a00787.html#adce28126e9bbd4ef005e3bf181d59745',1,'tds_time']]],
+  ['tm_5fns_359',['tm_ns',['../a00787.html#a386f1cfcabbe3ed86afe72bed75778cf',1,'tds_time']]],
+  ['tm_5fsec_360',['tm_sec',['../a00787.html#adeb5e3f535662c0341d28f8d669cb59b',1,'tds_time']]],
+  ['tm_5fyear_361',['tm_year',['../a00787.html#a3e27d50ebb5196356a6a8a9b495c8758',1,'tds_time']]],
+  ['tmp_5fbuf_362',['tmp_buf',['../a00651.html',1,'']]],
+  ['tmp_5fcol_5fstruct_363',['tmp_col_struct',['../a00747.html',1,'']]],
+  ['to_20add_20a_20new_20type_364',['How to add a new type',['../a01468.html',1,'']]],
+  ['todo_20list_365',['Todo List',['../a00581.html',1,'']]],
+  ['token_2ec_366',['token.c',['../a00251.html',1,'']]],
+  ['type_367',['type',['../a01468.html',1,'How to add a new type'],['../a01291.html#a889aafdde1d57c9be0585326022831f0',1,'tds_cursor::type']]]
 ];
